##
##  gstreamer.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         gstreamer
Summary:      Glib Streaming Library
URL:          https://gstreamer.freedesktop.org/
Vendor:       Erik Walthinsen et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Multimedia
License:      LGPL
Version:      1.26.2
Release:      20250530

#   list of sources
Source0:      https://gstreamer.freedesktop.org/src/gstreamer/gstreamer-%{version}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, pkgconfig, meson, ninja
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  glib
PreReq:       glib

%description
    GStreamer is a library for constructing graphs of media-handling
    components. The applications it supports range from simple
    Ogg/Vorbis playback, audio/video streaming to complex audio (mixing)
    and video (non-linear editing) processing.

%track
    prog gstreamer = {
        version   = %{version}
        url       = https://gstreamer.freedesktop.org/src/gstreamer/
        regex     = gstreamer-(__VER__)\.tar\.xz
    }

%prep
    %setup -q

%build
    #   configure package
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O} -Wno-deprecated-declarations" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    meson build \
        --prefix %{l_prefix} \
        --buildtype release \
        --default-library static \
        --backend ninja \
        -Dgst_debug=false \
        -Dcheck=disabled \
        -Dlibunwind=disabled \
        -Dlibdw=disabled \
        -Ddbghelp=disabled \
        -Dbash-completion=disabled \
        -Dcoretracers=disabled \
        -Dexamples=disabled \
        -Dtests=disabled \
        -Dbenchmarks=disabled \
        -Dintrospection=disabled \
        -Dnls=disabled \
        -Dgobject-cast-checks=disabled \
        -Dglib-asserts=disabled \
        -Dglib-checks=disabled \
        -Dextra-checks=disabled \
        -Ddoc=disabled

    #   build package
    ninja -C build

%install
    #   install package
    DESTDIR=$RPM_BUILD_ROOT ninja -C build install

    #   strip down installation
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/gdb
    rmdir $RPM_BUILD_ROOT%{l_prefix}/share >/dev/null 2>&1 || true

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

